<?php

namespace Drupal\resque\Queue;

use Drupal\Core\Queue\QueueInterface;
use Drupal\resque\DrupalWorkerJob;

/**
 * Class Resque.
 *
 * @package Drupal\resque\Queue
 */
class Resque implements QueueInterface {

  /**
   * Resque constructor.
   *
   * @param string $queue
   *   The queue name.
   */
  public function __construct(string $queue) {
    $this->queue = $queue;
  }

  /**
   * Contains the flag is the connection is established.
   *
   * @var bool
   */
  protected static $connectionEstablished;

  /**
   * The queue name of the current queue instance.
   *
   * @var string
   */
  protected $queue;

  /**
   * {@inheritdoc}
   */
  public function createItem($data) {
    return \Resque::enqueue($this->queue, DrupalWorkerJob::class, ['data' => $data]);
  }

  /**
   * {@inheritdoc}
   */
  public function numberOfItems() {
    return \Resque::size($this->queue);
  }

  /**
   * {@inheritdoc}
   */
  public function claimItem($lease_time = 3600) {
    return \Resque::pop($this->queue);
  }

  /**
   * {@inheritdoc}
   */
  public function deleteItem($item) {
    \Resque::dequeue($this->queue, [$item]);
  }

  /**
   * {@inheritdoc}
   */
  public function releaseItem($item) {
    \Resque::push($this->queue, $item);
  }

  /**
   * {@inheritdoc}
   */
  public function createQueue() {
    if (!static::$connectionEstablished) {
      /*
       * ToDo: Inject configuration management for connecting to the redis
       *    service.
       */
      \Resque::setBackend(getenv('REDIS_BACKEND'));
      static::$connectionEstablished = TRUE;
    }
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function deleteQueue() {
    \Resque::removeQueue($this->queue);
  }

}
